marktools.get_annotations_attached_to_component
===============================================

.. autofunction:: abjad.tools.marktools.get_annotations_attached_to_component.get_annotations_attached_to_component
